<img alt="AppVeyor" src="https://badgen.net/badge/build/on%20development/green"> [![star this repo](https://githubbadges.com/star.svg?user=MahanBi&repo=MakeDjango&style=default)](https://github.com/MahanBi/MakeDjango) [![fork this repo](https://githubbadges.com/fork.svg?user=MahanBi&repo=MakeDjango&style=default)](https://github.com/MahanBi/MakeDjango/fork)
# MakeDjango

MakeDjango: simple command line tool for start project
